@@ -1,5 +1,5 @@
 from . import meta  # noqa: 401
-from .formats import load_data  # noqa: 401
+from .formats import find_data, load_data  # noqa: 401
 from .formats import supported_extensions  # noqa: 401
 from .afm_fdist import AFMForceDistance  # noqa: 401
 
