@@ -40,7 +40,7 @@ def detect_txt(path):
     return valid
 
 
-def load_txt(path, callback=None, meta_override={}):
+def load_txt(path, callback=None, meta_override=None):
     """Load text files exported by the NT-MDT Nova software
 
     The columns are assumed to be: height (piezo) [nm],
@@ -61,13 +61,29 @@ def load_txt(path, callback=None, meta_override={}):
     not work for `exemplary data
     <https://doi.org/10.6084/m9.figshare.11862327.v1>`_. If the
     NT-MDT Nova software is not available, it should still be
-    possible to load the data with `Ggyddion <http://gwyddion.net>`
+    possible to load the data with `Ggyddion <http://gwyddion.net>`_
     and export it to something afmformats understands.
+
+    Parameters
+    ----------
+    path: str or pathlib.Path or io.TextIOBase
+        path to an ntmdt-exported .txt file
+    callback: callable
+        function for progress tracking; must accept a float in
+        [0, 1] as an argument.
+    meta_override: dict
+        if specified, contains key-value pairs of metadata that
+        are used when loading the files
+        (see :data:`afmformats.meta.META_FIELDS`)
     """
-    if ("sensitivity" not in meta_override
-            and "spring constant" not in meta_override):
+    if meta_override is None:
+        meta_override = {}
+    req_metadata = ["sensitivity", "spring constant"]
+    mis_metadata = [key for key in req_metadata if key not in meta_override]
+    if mis_metadata:
         raise errors.MissingMetaDataError(
-            "Please specify 'spring constant' and 'sensitivity'!")
+            mis_metadata,
+            f"Please specify {' and '.join(mis_metadata)}!")
 
     rawdata = np.loadtxt(path, converters=converters)
 
@@ -78,22 +94,24 @@ def load_txt(path, callback=None, meta_override={}):
     raw_apr = crop_beginning(rawdata[:, :2])
     raw_ret = crop_beginning(rawdata[:, ::2])
 
-    data = {}
-    data["height (measured)"] = np.concatenate((raw_apr[::-1, 0],
-                                                raw_ret[:, 0])) * 1e-9
+    data = {"height (measured)": np.concatenate((raw_apr[::-1, 0],
+                                                 raw_ret[:, 0])) * 1e-9}
     fmult = meta_override["sensitivity"] * meta_override["spring constant"]
     data["force"] = np.concatenate((raw_apr[::-1, 1],
                                     raw_ret[:, 1])) * fmult * 1e-9
     data["segment"] = np.concatenate((np.zeros(raw_apr.shape[0], dtype=bool),
                                       np.ones(raw_ret.shape[0], dtype=bool)))
 
-    metadata = {}
-    metadata["path"] = path
-    metadata["enum"] = 0
+    metadata = {"path": path,
+                "enum": 0}
     metadata.update(meta_override)
 
     dd = {"data": data,
           "metadata": metadata}
+
+    if callback is not None:
+        callback(1)
+
     return [dd]
 
 
