@@ -31,14 +31,35 @@ def detect_tab(path, max_header=1000):
     return has_begin and has_data and has_end
 
 
-def load_tab(path, callback=None, meta_override={}):
+def load_tab(path, callback=None, meta_override=None):
     """Loads tab-separated-value files as exported by afmformats
 
     This is a simple tab-separated values files. The metadata
     may be present at the beginning of the file, commented out,
     as a json dump in a "BEGIN METADATA" - "END METADATA" block.
     The column data is listed below as a simple table.
+
+    Parameters
+    ----------
+    path: str or pathlib.Path or io.TextIOBase
+        path to a .tab file
+    callback: callable
+        function for progress tracking; must accept a float in
+        [0, 1] as an argument.
+    meta_override: dict
+        if specified, contains key-value pairs of metadata that
+        are used when loading the files
+        (see :data:`afmformats.meta.META_FIELDS`)
     """
+    if meta_override is None:
+        meta_override = {}
+    else:
+        # just make sure nobody expects a different result for the forces
+        for key in ["sensitivity", "spring constant"]:
+            if key in meta_override:
+                raise NotImplementedError(
+                    f"Setting metadata such as '{key}' is not implemented!")
+
     path = pathlib.Path(path)
     with path.open() as fd:
         tsvdata = fd.readlines()
@@ -94,6 +115,10 @@ def load_tab(path, callback=None, meta_override={}):
     metadata.update(meta_override)
     dd = {"data": data,
           "metadata": metadata}
+
+    if callback is not None:
+        callback(1)
+
     return [dd]
 
 
