@@ -1,17 +1,19 @@
 import pathlib
 
+from . import errors
 from .fmt_hdf5 import recipe_hdf5
 from .fmt_igor import recipe_ibw
 from .fmt_jpk import recipe_jpk_force, recipe_jpk_force_map, \
     recipe_jpk_force_qi
 from .fmt_tab import recipe_tab
 from .fmt_ntmdt_txt import recipe_ntmdt_txt
-from .fmt_workshop import recipe_workshop
+from .fmt_workshop import recipe_workshop_single, recipe_workshop_map
 from .afm_fdist import AFMForceDistance
 
 
-__all__ = ["AFMFormatRecipe", "load_data", "formats_available",
-           "formats_by_suffix", "formats_by_mode", "supported_extensions"]
+__all__ = ["AFMFormatRecipe", "find_data", "get_recipe", "load_data",
+           "formats_available", "formats_by_suffix", "formats_by_mode",
+           "supported_extensions"]
 
 
 #: supported imaging modalities
@@ -121,28 +123,84 @@ class AFMFormatRecipe(object):
         return valid
 
 
+def find_data(path, mode=None):
+    """Recursively find valid AFM data files
+
+    Parameters
+    ----------
+    path: str or pathlib.Path
+        file or directory
+    mode: str
+        mode of the measurement ("force-distance")
+
+    Returns
+    -------
+    file_list: list of pathlib.Path
+        list of valid AFM data files
+    """
+    path = pathlib.Path(path)
+    file_list = []
+    if path.is_dir():
+        # recurse into subdirectories
+        for pp in path.rglob("*"):
+            if pp.is_file():
+                file_list += find_data(pp, mode=mode)
+    else:
+        try:
+            get_recipe(path=path, mode=mode)
+        except errors.FileFormatNotSupportedError:
+            # not a valid file format
+            pass
+        else:
+            # valid file format
+            file_list.append(path)
+    return file_list
+
+
 def get_recipe(path, mode=None):
+    """Return the file format recipe for a given path
+
+    Parameters
+    ----------
+    path: str or pathlib.Path
+        file or directory
+    mode: str
+        mode of the measurement ("force-distance")
+
+    Returns
+    -------
+    recipe: dict
+        file format recipe
+    """
     path = pathlib.Path(path)
     if mode is None:
         # TODO:
         # - Try to figure out the mode somehow
         mode = "force-distance"
 
+    if path.suffix not in formats_by_suffix:
+        raise errors.FileFormatNotSupportedError(
+            f"No recipe for suffix '{path.suffix}' (file '{path}')!")
+
     recipes = formats_by_suffix[path.suffix]
     for rec in recipes:
         if rec.mode == mode and rec.detect(path):
             break
     else:
-        raise ValueError("Could not determine recipe for '{}'!".format(path))
+        raise errors.FileFormatNotSupportedError(
+            f"Could not determine file format recipe for '{path}'!")
+
     return rec
 
 
 def load_data(path, mode=None, diskcache=False, callback=None,
-              meta_override={}):
+              meta_override=None):
     """Load AFM data
 
     Parameters
     ----------
+    path: str or pathlib.Path
+        Path to AFM data file
     mode: str
         Which acquisition mode to use (currently only "force-distance")
     diskcache: bool
@@ -153,15 +211,17 @@ def load_data(path, mode=None, diskcache=False, callback=None,
     meta_override: dict
         Metadata dictionary that overrides experimental metadata
     """
+    if meta_override is None:
+        meta_override = {}
     path = pathlib.Path(path)
     if path.suffix in formats_by_suffix:
         afmdata = []
-        recipe = get_recipe(path, mode)
-        loader = recipe.loader
+        cur_recipe = get_recipe(path, mode)
+        loader = cur_recipe.loader
         for dd in loader(path, callback=callback,
                          meta_override=meta_override):
-            dd["metadata"]["format"] = "{} ({})".format(recipe["maker"],
-                                                        recipe["descr"])
+            dd["metadata"]["format"] = "{} ({})".format(cur_recipe["maker"],
+                                                        cur_recipe["descr"])
             ddi = AFMForceDistance(data=dd["data"],
                                    metadata=dd["metadata"],
                                    diskcache=diskcache)
@@ -201,7 +261,7 @@ formats_by_mode = {}
 #: list of supported extensions
 supported_extensions = []
 
-for recipe in [
+for _recipe in [
     recipe_hdf5,
     recipe_ibw,
     recipe_jpk_force,
@@ -209,6 +269,7 @@ for recipe in [
     recipe_jpk_force_qi,
     recipe_ntmdt_txt,
     recipe_tab,
-    recipe_workshop,
+    recipe_workshop_map,
+    recipe_workshop_single,
 ]:
-    register_format(recipe)
+    register_format(_recipe)
